@@ -1,6 +1,8 @@
+//! Configuration of the installed systemd-boot environment.
+
 use std::{fs, path::Path, str::FromStr};
 
-use crate::LibSDBootConfError;
+use crate::{generate_builder_method, LibSDBootConfError};
 
 /// An abstraction over the configuration file of systemd-boot.
 #[derive(Default, Debug)]
@@ -103,3 +105,36 @@ impl Config {
         Ok(())
     }
 }
+
+/// Builder for Config.
+#[derive(Default, Debug)]
+pub struct ConfigBuilder {
+    config: Config,
+}
+
+impl ConfigBuilder {
+    /// Create an empty ConfigBuilder.
+    pub fn new() -> Self {
+        Self { config: Config::default() }
+    }
+
+    generate_builder_method!(option default, impl Into<String>);
+    generate_builder_method!(option timeout, i32);
+
+    /// Build the Config.
+    pub fn build(self) -> Config {
+        self.config
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn test_builder() {
+        let entry = ConfigBuilder::new().default("5.12.0-aosc-main").build();
+
+        println!("{:?}", &entry);
+    }
+}
